<?php

class HighLighter extends Plugin {

	/**
	 * *************************************************************
	 *
	 * Gibt den HTML-Code zurück, mit dem die Plugin-Variable ersetzt
	 * wird. Der String-Parameter $value ist Pflicht, kann aber leer
	 * sein.
	 *
	 * *************************************************************
	 */
	function getContent($value) {
		global $specialchars;

		// Kein Parameter übergeben?
		if ($value == "") {
			return $this->buildErrorMsg("Kein Parameter übergeben.");
		}

		// Eingaben aufdröseln:
		$pipePos = strpos($value, "|");
		// Sprache...
		$language = substr($value, 0, $pipePos);
		// ...und zu highlightender Code
		$code = substr($value, $pipePos + 1, strlen($value));
		// Plugin-Ersetzungen und Zeilenwechsel normalisieren
		$code = str_replace(array(
			'~noplugin_start-',
			'-noplugin_end~',
			'-noplugin_grade~',
			'<br />'
		), array(
			'{',
			'}',
			'|',
			''
		), $code);
		// Leerzeilen vor und hinter dem Code trimmen
		$code = trim($code, "\r\n");
		// HTML-Entities auflösen
		$code = $specialchars->getHtmlEntityDecode($code);

		// Jetzt das eigentliche Highlighting mit GeSHi
		include_once 'plugins/HighLighter/geshi.php';
		$geshi = new GeSHi($code, $language);
		$geshi->set_header_type(GESHI_HEADER_PRE_VALID);
		// CSS-Klasse fürs GeSHi-DIV
		$geshi->set_overall_class('highlighter_plugin');
		// Kleiner Trick: Der Header soll nicht manuell gestylt werden, sondern auch eine eigene CSS-Klasse bekommen
		$geshi->set_header_content_style("\" class=\"highlighter_plugin_header");

		// Zeilennummern
		if ($this->settings->get("enable_line_numbers") == "true") {
			$geshi->enable_line_numbers(GESHI_NORMAL_LINE_NUMBERS);
		}
		// Keywords verlinken
		if ($this->settings->get("enable_keyword_links") != "true") {
			$geshi->enable_keyword_links(false);
		}
		// Header
		if ($this->settings->get("display_header") == "true") {
			$geshi->set_header_content("{LANGUAGE}:");
		}

		return $geshi->parse_code();
	}

	// function getContent

	/**
	 * *************************************************************
	 *
	 * Gibt die Konfigurationsoptionen als Array zurück.
	 * Ist keine Konfiguration nötig, ist dieses Array leer.
	 *
	 * *************************************************************
	 */
	function getConfig() {
		// Rückgabe-Array initialisieren
		// Das muß auf jeden Fall geschehen!
		$config = array();

		$config ['enable_line_numbers'] = array(
			"type" => "checkbox",
			"description" => "Zeilennummern anzeigen"
		);
		$config ['enable_keyword_links'] = array(
			"type" => "checkbox",
			"description" => "Keywords verlinken"
		);
		$config ['display_header'] = array(
			"type" => "checkbox",
			"description" => "Header anzeigen"
		);

		// Nicht vergessen: Das gesamte Array zurückgeben
		return $config;
	}

	// function getConfig

	/**
	 * *************************************************************
	 *
	 * Gibt die Plugin-Infos als Array zurück - in dieser
	 * Reihenfolge:
	 * - Name und Version des Plugins
	 * - für moziloCMS-Version
	 * - Kurzbeschreibung
	 * - Name des Autors
	 * - Download-URL
	 * - Platzhalter für die Selectbox
	 *
	 * *************************************************************
	 */
	function getInfo() {
		$info = array(
			// Plugin-Name + Version
			"<b>HighLighter</b> 1.1.2022-02-12",
			// moziloCMS-Version
			"1.12",
			// Kurzbeschreibung nur <span> und <br /> sind erlaubt
			"Einbindung des freien Syntax-Highlighters GeSHi in moziloCMS.<br />" . "GeSHi unterstützt Syntaxhervorhebung für fast 200 Programmiersprachen.<br />" . "Verwendendete GeSHi-Version: 1.0.8.9<br />" . "GeSHi im Netz: http://qbnz.com/highlighter/<br />" . "<br />" . $this->fett("Nutzung:") . "<br />" . "{HighLighter|" . $this->blau("Sprache") . "|" . $this->rot("Code") . "}<br />" . $this->kursiv("Nutzbar sind alle im Plugin-Unterverzeichnis \"geshi\" vorhandenen Sprachen. Groß-/Kleinschreibung ist dabei egal; \"Java\" = \"JAVA\" = \"java\" = \"jAvA\".") . "<br />" . "<br />" . $this->fett("Beispiele:") . "<br />" . "{HighLighter|" . $this->blau("php") . "|<br />" . $this->rot("print \"Hallo Welt!\";") . "<br />" . "}<br />" . "<br />" . "{HighLighter|" . $this->blau("java") . "|<br />" . $this->rot("System.out.println(\"Hallo Welt!\");") . "<br />" . "}",
			// Name des Autors
			"Arvid Zimmermann",
			// Download-URL
			"https://www.arvidzimmermann.de",
			// Platzhalter für die Selectbox in der Editieransicht
			// - ist das Array leer, erscheint das Plugin nicht in der Selectbox
			array(
				'{HighLighter|Sprache|Code}' => 'Syntax-Highlighting'
			)
		);
		// Rückgabe der Infos
		return $info;
	}

	// function getInfo

	// Zusatzfunktion: Gibt Fehlermeldung aus
	function buildErrorMsg($msg) {
		return '<span class="deadlink">Fehler im Plugin ankerlink: ' . $msg . '</span>';
	}

	// Ausgabe-Funktionen
	function rot($text) {
		return "<span style=\"color:#b22;\">$text</span>";
	}

	function blau($text) {
		return "<span style=\"color:#22b;\">$text</span>";
	}

	function fett($text) {
		return "<span style=\"font-weight:bold;\">$text</span>";
	}

	function kursiv($text) {
		return "<span style=\"font-style:italic;\">$text</span>";
	}

} // class HighLighter

?>